==> monica-3.7.0p0.tgz: www/monica/resources/lang/el/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Υπενθύμιση για :contact',
    'greetings' => 'Γεια σου :username',
    'want_reminded_of' => 'Είχατε ζητήσει υπενθύμιση για :reason',
    'for' => 'Προς: :name',
    'comment' => 'Σχόλιο: :comment',
    'footer_contact_info' => 'Προσθέστε, δείτε, ολοκληρώστε και επεξεργαστείτε τις πληροφορίες για αυτή την επαφή:',
    'footer_contact_info2' => 'Δείτε το προφίλ του :name',
    'footer_contact_info2_link' => 'Δείτε τη διεύθυνση του προφίλ του :name',

    'notification_subject_line' => 'Έχετε μια επερχόμενη εκδήλωση',
    'notification_description' => 'Σε :count ημέρες (:date) έχετε την επόμενη εκδήλωση:',

    'stay_in_touch_subject_line' => 'Μείνετε σε επαφή με :name',
    'stay_in_touch_subject_description' => 'Ζητήσατε να σας υπενθυμίζουμε να μένετε σε επαφή με τον :name κάθε :frequency μέρα.|Ζητήσατε να σας υπενθυμίζουμε να μένετε σε επαφή με τον :name κάθε :frequency μέρες.',

    'notifications_whoops' => 'Ουπς!',
    'notifications_hello' => 'Γειά!',
    'notifications_regards' => 'Με εκτίμηση,',
    'notifications_footer' => 'Εάν αντιμετωπίζετε προβλήματα κάνοντας κλικ στο κουμπί ":actionText", αντιγράψτε και επικολλήστε την παρακάτω διεύθυνση URL στο πρόγραμμα περιήγησης: [:actionURL] (:actionURL)',
    'notifications_rights' => 'Με επιφύλαξη παντός δικαιώματος',

    'confirmation_email_title' => 'Monica – Email επιβεβαίωσης',
    'confirmation_email_intro'=> 'Για να επιβεβαιώσετε το email σας, πατήστε στο παρακάτω κουμπί',
    'confirmation_email_button' => 'Επιβεβαίωση διεύθυνσης email',
    'confirmation_email_bottom' => 'Αν δεν δημιουργήστε έναν λογαριασμό, δεν χρειάζεται κάποια περαιτέρω ενέργεια.',

    'password_reset_title' => 'Monica – Ειδοποίηση Επαναφοράς Κωδικού Πρόσβασης',
    'password_reset_intro' => 'Λαμβάνετε αυτό το email γιατί λάβαμε μία αίτηση για επαναφορά κωδικού πρόσβασης για αυτό το λογαριασμό.',
    'password_reset_button' => 'Επαναφορά κωδικού πρόσβασης',
    'password_reset_expiration' => 'Αυτός ο σύνδεσμος επαναφοράς κωδικού πρόσβασης θα λήξει σε :count λεπτά.',
    'password_reset_bottom' => 'Αν δεν ζητήσατε επαναφορά κωδικού πρόσβασης, δεν χρειάζεται κάποια περαιτέρω ενέργεια.',

    'invitation_title' => 'Monica – Η επαφή :name σας έχει προσκαλέσει',
    'invitation_intro' => 'Η επαφή :name (:email) σας προσκάλεσε να χρησιμοποιήσετε το Monica, ένα ωραίο εργαλείο Διαχείρισης Προσωπικών Σχέσεων.',
    'invitation_link' => 'Για να αποδεχτείτε την πρόσκληση, πατήστε στον σύνδεσμο παρακάτω:',
    'invitation_button' => 'Αποδοχή πρόσκλησης',
    'invitation_expiration' => 'Ο σύνδεσμος θα λήξει σε :count μέρες.',

    'export_title' => 'Your export is ready',
    'export_description' => 'You requested a data export on :date. It is now ready to download.',
    'export_download' => 'Download export',

];

==> monica-4.1.2.tgz: www/monica/resources/lang/el/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Υπενθύμιση για :contact',
    'greetings' => 'Γεια σου :username',
    'want_reminded_of' => 'Είχατε ζητήσει υπενθύμιση για :reason',
    'for' => 'Προς: :name',
    'comment' => 'Σχόλιο: :comment',
    'footer_contact_info' => 'Προσθέστε, δείτε, ολοκληρώστε και επεξεργαστείτε τις πληροφορίες για αυτή την επαφή:',
    'footer_contact_info2' => 'Δείτε το προφίλ του :name',
    'footer_contact_info2_link' => 'Δείτε τη διεύθυνση του προφίλ του :name',

    'notification_subject_line' => 'Έχετε μια επερχόμενη εκδήλωση',
    'notification_description' => 'Σε :count ημέρες (:date) έχετε την επόμενη εκδήλωση:',

    'stay_in_touch_subject_line' => 'Μείνετε σε επαφή με :name',
    'stay_in_touch_subject_description' => 'Ζητήσατε να σας υπενθυμίζουμε να μένετε σε επαφή με τον :name κάθε :frequency μέρα.|Ζητήσατε να σας υπενθυμίζουμε να μένετε σε επαφή με τον :name κάθε :frequency μέρες.',

    'notifications_whoops' => 'Ουπς!',
    'notifications_hello' => 'Γειά!',
    'notifications_regards' => 'Με εκτίμηση,',
    'notifications_footer' => 'Εάν αντιμετωπίζετε προβλήματα κάνοντας κλικ στο κουμπί ":actionText", αντιγράψτε και επικολλήστε την παρακάτω διεύθυνση URL στο πρόγραμμα περιήγησης: [:actionURL] (:actionURL)',
    'notifications_rights' => 'Με επιφύλαξη παντός δικαιώματος',

    'confirmation_email_title' => 'Monica – Email επιβεβαίωσης',
    'confirmation_email_intro'=> 'Για να επιβεβαιώσετε το email σας, πατήστε στο παρακάτω κουμπί',
    'confirmation_email_button' => 'Επιβεβαίωση διεύθυνσης email',
    'confirmation_email_bottom' => 'Αν δεν δημιουργήστε έναν λογαριασμό, δεν χρειάζεται κάποια περαιτέρω ενέργεια.',

    'password_reset_title' => 'Monica – Ειδοποίηση Επαναφοράς Κωδικού Πρόσβασης',
    'password_reset_intro' => 'Λαμβάνετε αυτό το email γιατί λάβαμε μία αίτηση για επαναφορά κωδικού πρόσβασης για αυτό το λογαριασμό.',
    'password_reset_button' => 'Επαναφορά κωδικού πρόσβασης',
    'password_reset_expiration' => 'Αυτός ο σύνδεσμος επαναφοράς κωδικού πρόσβασης θα λήξει σε :count λεπτά.',
    'password_reset_bottom' => 'Αν δεν ζητήσατε επαναφορά κωδικού πρόσβασης, δεν χρειάζεται κάποια περαιτέρω ενέργεια.',

    'invitation_title' => 'Monica – Η επαφή :name σας έχει προσκαλέσει',
    'invitation_intro' => 'Η επαφή :name (:email) σας προσκάλεσε να χρησιμοποιήσετε το Monica, ένα ωραίο εργαλείο Διαχείρισης Προσωπικών Σχέσεων.',
    'invitation_link' => 'Για να αποδεχτείτε την πρόσκληση, πατήστε στον σύνδεσμο παρακάτω:',
    'invitation_button' => 'Αποδοχή πρόσκλησης',
    'invitation_expiration' => 'Ο σύνδεσμος θα λήξει σε :count μέρες.',

    'export_title' => 'Το αρχείο εξαγωγής δεδομένων είναι έτοιμο',
    'export_description' => 'Ζητήσατε εξαγωγή δεδομένων στις :date. Τώρα είναι έτοιμο για λήψη.',
    'export_download' => 'Λήψη εξαγωγής δεδομένων',

];
